@@ -7,7 +7,7 @@ package Circle::FE::Term;
 use strict;
 use warnings;
 
-our $VERSION = '0.140961';
+our $VERSION = '0.153000';
 
 use File::ShareDir qw( dist_file );
 
@@ -74,6 +74,15 @@ sub get_theme_colour
    return undef;
 }
 
+my %theme_pens;
+
+sub get_theme_pen
+{
+   my $class = shift;
+   my ( $varname ) = @_;
+   return $theme_pens{$varname} ||= Tickit::Pen->new( fg => $class->get_theme_colour( $varname ) );
+}
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
