@@ -1,6 +1,6 @@
 #  You may distribute under the terms of the GNU General Public License
 #
-#  (C) Paul Evans, 2010-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2015 -- leonerd@leonerd.org.uk
 
 package Circle::FE::Term::Widget::Entry;
 
@@ -29,21 +29,18 @@ sub build
          $pending_count++;
          $self->send_pending( $pending_count );
 
-         $obj->call_method(
-            method => "enter",
-            args => [ $self->text ],
-
-            on_result => sub {
+         $tab->adopt_future(
+            $obj->call_method(
+               enter => $self->text,
+            )->on_done( sub {
                $pending_count--;
                $self->send_pending( $pending_count );
-            },
-
-            on_error => sub {
+            })->on_fail( sub {
                my ( $message ) = @_;
                # TODO: write the error message somewhere
                $pending_count--;
                $self->send_pending( $pending_count );
-            },
+            })
          );
 
          $self->set_text( "" ) if $autoclear;
@@ -51,26 +48,29 @@ sub build
       },
    );
 
-   $obj->watch_property(
-      property => "text",
-      on_set => sub {
-         my ( $text ) = @_;
-         $text = "" unless defined $text;
-         $widget->set_text( $text );
-      },
-      want_initial => 1,
+   $tab->adopt_future(
+      $obj->watch_property_with_initial(
+         "text",
+         on_set => sub {
+            my ( $text ) = @_;
+            $text = "" unless defined $text;
+            $widget->set_text( $text );
+         },
+      )
    );
 
-   $obj->watch_property(
-      property => "history",
-      on_updated => sub {}, # We ignore this, we just want a local cache
-      want_initial => 1,
+   $tab->adopt_future(
+      $obj->watch_property_with_initial(
+         "history",
+         on_updated => sub {}, # We ignore this, we just want a local cache
+      )
    );
 
-   $obj->watch_property(
-      property => "completions",
-      on_updated => sub {}, # We ignore this, we just want a local cache
-      want_initial => 1,
+   $tab->adopt_future(
+      $obj->watch_property_with_initial(
+         "completions",
+         on_updated => sub {}, # We ignore this, we just want a local cache
+      )
    );
 
    $widget->bind_keys(
